@@ -11,8 +11,16 @@ from . import gandi_api
 logger = logging.getLogger(__name__)
 
 
-@zope.interface.implementer(interfaces.IAuthenticator)
-@zope.interface.provider(interfaces.IPluginFactory)
+def register_authenticator(cls):
+    try:
+        interfaces.Authenticator.register(cls)
+    except AttributeError:
+        pass
+    zope.interface.implementer(interfaces.IAuthenticator)(cls) 
+    zope.interface.provider(interfaces.IPluginFactory)(cls)
+    return cls 
+    
+@register_authenticator
 class Authenticator(dns_common.DNSAuthenticator):
     """DNS Authenticator for Gandi (using LiveDNS)."""
 
@@ -20,9 +28,6 @@ class Authenticator(dns_common.DNSAuthenticator):
 
 
     def __init__(self, config, name, **kwargs):
-        if name in ("dns", "certbot-plugin-gandi:dns"):
-            logger.warning("Certbot is moving to remove 3rd party plugins prefixes. Please use --authenticator dns-gandi --dns-gandi-credentials")
-
         super(Authenticator, self).__init__(config, name, **kwargs)
         self.credentials = None
 
